# CIDAN

# Install Instructions
1. Make sure you have anaconda installed.
2. Run these commands:

```
conda create -n CIDAN python=3.7
conda activate CIDAN
pip install CIDAN
python -m CIDAN
```
If you encounter an error in the installation of hnswlib, please install Microsoft C++ build tools: https://visualstudio.microsoft.com/visual-cpp-build-tools/ 

If you encounter another issue in the installation or running of the package please post an issue to the github repo and we will get back to you.
